@@ -485,7 +485,7 @@ response_cb (GtkDialog *dialog,
     {
     case GTK_RESPONSE_HELP:
       gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-                    "ghelp:mate-dictionary#mate-dictionary-preferences",
+                    "help:mate-dictionary/mate-dictionary-preferences",
                     gtk_get_current_event_time (), &err);
       if (err)
 	{
