@@ -93,7 +93,6 @@ static GdkPixbuf *screenshot = NULL;
 
 /* Global variables*/
 static char *last_save_dir = NULL;
-static char *window_title = NULL;
 static char *temporary_file = NULL;
 static gboolean save_immediately = FALSE;
 static GSettings *settings = NULL;
@@ -903,10 +902,7 @@ build_uri (AsyncExistenceJob *job)
   GDateTime *d;
 
   d = g_date_time_new_now_local ();
-  /* Translators: This is a strftime format string.
-   * It is used to display the time in 24-hours format (eg, like
-   * in France: 20:10) but using hyphens in place of colons. */
-  timestamp = g_date_time_format (d, _("%Y-%m-%d %H-%M-%S"));
+  timestamp = g_date_time_format (d, "%Y-%m-%d %H-%M-%S");
   g_date_time_unref (d);
 
   if (job->iteration == 0)
@@ -1026,7 +1022,7 @@ out:
 }
 
 static GdkWindow *
-find_current_window (char **window_title)
+find_current_window (void)
 {
   GdkWindow *window;
 
@@ -1041,15 +1037,6 @@ find_current_window (char **window_title)
 	  take_window_shot = FALSE;
 	  window = gdk_get_default_root_window ();
 	}
-      else
-	{
-	  gchar *tmp, *sanitized;
-
-	  tmp = screenshot_get_window_title (window);
-	  sanitized = screenshot_sanitize_filename (tmp);
-	  g_free (tmp);
-	  *window_title = sanitized;
-	}
     }
   else
     {
@@ -1071,7 +1058,7 @@ push_check_file_job (GdkRectangle *rectangle)
   job->base_uris[2] = g_strconcat ("file://", g_get_tmp_dir (), NULL);
   job->iteration = 0;
   job->type = TEST_LAST_DIR;
-  job->window = find_current_window (&window_title);
+  job->window = find_current_window ();
 
   if (rectangle != NULL)
     {
